changeset 944:f5a4283de843

6324156 prtdiag needs to look for pciex class in addition to pci class 6329025 prtfru output has no PCI slots info 6305824 frutree subtree has extra system-fan1 in picl tree on UP Chicago
author venki
date Fri, 18 Nov 2005 04:44:44 -0800
parents 19aae6d81452
children 8a803989ced9
files usr/src/cmd/picl/plugins/common/devtree/picldevtree.c usr/src/cmd/picl/plugins/inc/picldefs.h usr/src/cmd/picl/plugins/sun4u/chicago/frutree/piclfrutree.info usr/src/cmd/picl/plugins/sun4u/chicago/frutree/system-board.info
diffstat 4 files changed, 25 insertions(+), 26 deletions(-) [+]
line wrap: on
line diff
--- a/usr/src/cmd/picl/plugins/inc/picldefs.h	Thu Nov 17 15:04:51 2005 -0800
+++ b/usr/src/cmd/picl/plugins/inc/picldefs.h	Fri Nov 18 04:44:44 2005 -0800
@@ -20,7 +20,7 @@
  * CDDL HEADER END
  */
 /*
- * Copyright 2004 Sun Microsystems, Inc.  All rights reserved.
+ * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
@@ -86,6 +86,7 @@
 #define	PICL_CLASS_CPU			"cpu"
 #define	PICL_CLASS_UPA			"upa"
 #define	PICL_CLASS_PCI			"pci"
+#define	PICL_CLASS_PCIEX		"pciex"
 #define	PICL_CLASS_PMU			"pmu"
 #define	PICL_CLASS_SOUND		"sound"
 #define	PICL_CLASS_SBUS			"sbus"
--- a/usr/src/cmd/picl/plugins/sun4u/chicago/frutree/piclfrutree.info	Thu Nov 17 15:04:51 2005 -0800
+++ b/usr/src/cmd/picl/plugins/sun4u/chicago/frutree/piclfrutree.info	Fri Nov 18 04:44:44 2005 -0800
@@ -93,14 +93,12 @@
 	NODE F0 location
 	    PROP SlotType string r 0 "fan-unit"
 	    PROP Label string r 0 "F0"
-	    NODE system-fan0 fru
-	    ENDNODE
+	    REFNODE system-fan0 fru WITH _class:/PLATFORM_CLASS/cpu?ID=0
 	ENDNODE
 	NODE F1 location
 	    PROP SlotType string r 0 "fan-unit"
 	    PROP Label string r 0 "F1"
-	    NODE system-fan1 fru
-	    ENDNODE
+	    REFNODE system-fan1 fru WITH _class:/PLATFORM_CLASS/cpu?ID=1
 	ENDNODE
 	NODE F2 location
 	    PROP SlotType string r 0 "fan-unit"
--- a/usr/src/cmd/picl/plugins/sun4u/chicago/frutree/system-board.info	Thu Nov 17 15:04:51 2005 -0800
+++ b/usr/src/cmd/picl/plugins/sun4u/chicago/frutree/system-board.info	Fri Nov 18 04:44:44 2005 -0800
@@ -142,19 +142,19 @@
  * Populate PCI slots
  */
 name:/frutree/chassis/MB/system-board/pci-slot?Label=PCI4
-REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pci@1f,700000/picl?DeviceID=0
+REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pciex@1f,700000/picl?DeviceID=0
 
 name:/frutree/chassis/MB/system-board/pci-slot?Label=PCI3
-REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pci@1e,600000/pci@0/pci@8/picl?DeviceID=0
+REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pciex@1e,600000/pciex@0/pciex@8/picl?DeviceID=0
 
 name:/frutree/chassis/MB/system-board/pci-slot?Label=PCI2
-REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pci@1e,600000/pci@0/pci@3/picl?DeviceID=0
+REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pciex@1e,600000/pciex@0/pciex@3/picl?DeviceID=0
 
 name:/frutree/chassis/MB/system-board/pci-slot?Label=PCI1
-REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pci@1e,600000/pci@0/pci@9/pci@0,2/picl?DeviceID=1
+REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pciex@1e,600000/pciex@0/pciex@9/pciex@0,2/picl?DeviceID=1
 
 name:/frutree/chassis/MB/system-board/pci-slot?Label=PCI0
-REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pci@1e,600000/pci@0/pci@9/pci@0,2/picl?DeviceID=2
+REFNODE pci-card fru WITH _class:/PLATFORM_CLASS/pciex@1e,600000/pciex@0/pciex@9/pciex@0,2/picl?DeviceID=2
 
 /*
  * SEEPROM source for the motherboard
@@ -250,19 +250,19 @@
 /*
  * _fru_parent PCI devices
  */
-_class:/PLATFORM_CLASS/pci@1f,700000/picl?DeviceID=0
+_class:/PLATFORM_CLASS/pciex@1f,700000/picl?DeviceID=0
 REFPROP _fru_parent /frutree/chassis/MB/system-board/pci-slot?Label=PCI4/pci-card
 
-_class:/PLATFORM_CLASS/pci@1e,600000/pci@0/pci@8/picl?DeviceID=0
+_class:/PLATFORM_CLASS/pciex@1e,600000/pciex@0/pciex@8/picl?DeviceID=0
 REFPROP _fru_parent /frutree/chassis/MB/system-board/pci-slot?Label=PCI3/pci-card
 
-_class:/PLATFORM_CLASS/pci@1e,600000/pci@0/pci@3/picl?DeviceID=0
+_class:/PLATFORM_CLASS/pciex@1e,600000/pciex@0/pciex@3/picl?DeviceID=0
 REFPROP _fru_parent /frutree/chassis/MB/system-board/pci-slot?Label=PCI2/pci-card
 
-_class:/PLATFORM_CLASS/pci@1e,600000/pci@0/pci@9/pci@0,2/picl?DeviceID=1
+_class:/PLATFORM_CLASS/pciex@1e,600000/pciex@0/pciex@9/pciex@0,2/picl?DeviceID=1
 REFPROP _fru_parent /frutree/chassis/MB/system-board/pci-slot?Label=PCI1/pci-card
 
-_class:/PLATFORM_CLASS/pci@1e,600000/pci@0/pci@9/pci@0,2/picl?DeviceID=2
+_class:/PLATFORM_CLASS/pciex@1e,600000/pciex@0/pciex@9/pciex@0,2/picl?DeviceID=2
 REFPROP _fru_parent /frutree/chassis/MB/system-board/pci-slot?Label=PCI0/pci-card
 
 /*
--- a/usr/src/cmd/picl/plugins/common/devtree/picldevtree.c	Thu Nov 17 15:04:51 2005 -0800
+++ b/usr/src/cmd/picl/plugins/common/devtree/picldevtree.c	Fri Nov 18 04:44:44 2005 -0800
@@ -250,6 +250,7 @@
 	{PICL_CLASS_JBUS, encode_gptwo_jbus_unitaddr, 0},
 	{PICL_CLASS_GPTWO, encode_gptwo_jbus_unitaddr, 0},
 	{PICL_CLASS_PCI, encode_pci_unitaddr, 0},
+	{PICL_CLASS_PCIEX, encode_pci_unitaddr, 0},
 	{PICL_CLASS_UPA, encode_upa_unitaddr, 0},
 	{PICL_CLASS_SCSI, encode_scsi_unitaddr, 0},
 	{PICL_CLASS_SCSI2, encode_scsi_unitaddr, 0},
@@ -264,7 +265,7 @@
 static int add_unitaddr_prop_to_subtree(picl_nodehdl_t nodeh);
 static int get_unitaddr(picl_nodehdl_t parh, picl_nodehdl_t nodeh,
 	char *unitaddr, size_t ualen);
-
+static void set_pci_pciex_deviceid(picl_nodehdl_t plafh);
 
 /*
  * The mc event completion handler.
@@ -2689,7 +2690,7 @@
 }
 
 /*
  * add DeviceID property for children of PCI node
  */
 /* ARGSUSED */
 static int
@@ -2719,19 +2720,18 @@
 }
 
 /*
  * This function creates a DeviceID property for PCI child nodes
  * which can be correlated with the slot they are plugged into
  * on the motherboard.
  */
-static int
-set_pci_deviceid(picl_nodehdl_t plafh)
+static void
+set_pci_pciex_deviceid(picl_nodehdl_t plafh)
 {
-	int		err;
-
-	err = ptree_walk_tree_by_class(plafh, PICL_CLASS_PCI, NULL,
+	(void) ptree_walk_tree_by_class(plafh, PICL_CLASS_PCI, NULL,
 	    add_pci_deviceids);
 
-	return (err);
+	(void) ptree_walk_tree_by_class(plafh, PICL_CLASS_PCIEX, NULL,
+	    add_pci_deviceids);
 }
 
 /*
@@ -3222,7 +3222,7 @@
 
 	(void) add_platform_info(plafh);
 
-	(void) set_pci_deviceid(plafh);
+	set_pci_pciex_deviceid(plafh);
 
 	(void) set_sbus_slot(plafh);
 
@@ -3426,7 +3426,7 @@
 done:
 	(void) setup_cpus(plafh);
 	(void) add_ffb_config_info(plafh);
-	(void) set_pci_deviceid(plafh);
+	set_pci_pciex_deviceid(plafh);
 	(void) set_sbus_slot(plafh);
 	if (picldevtree_debug > 1)
 		syslog(LOG_INFO, "picldevtree: event handler done\n");
@@ -2689,7 +2690,7 @@
 
 /*
- * add DeviceID property for children of PCI node
+ * add DeviceID property for children of PCI/PCIEX node
  */
 /* ARGSUSED */
@@ -2719,19 +2720,18 @@
 
 /*
- * This function creates a DeviceID property for PCI child nodes
+ * This function creates a DeviceID property for PCI/PCIEX child nodes
  * which can be correlated with the slot they are plugged into
  * on the motherboard.